@@ -17,14 +17,12 @@ require DynaLoader;
 
 @ISA = qw(Exporter DynaLoader);
 @EXPORT = qw();
-$VERSION = '0.09';
+$VERSION = '0.20';
 
 bootstrap XML::Xalan::Transformer $VERSION;
 XML::Xalan::Transformer::initialize();
 
 *errstr = \&XML::Xalan::Transformer::getLastError;
-*destroy_stylesheet = \&XML::Xalan::Transformer::destroyStylesheet;
-*destroy_parsed_source = \&XML::Xalan::Transformer::destroyParsedSource;
 
 1;
 __END__
@@ -170,18 +168,91 @@ Example:
      $xmlfile, $xslfile, 
      *STDERR, $out_handler);
 
+=item $tr->destroy_stylesheet($compiled_stylesheet)
+
+Removes $compiled_stylesheet from memory.
+
+=item $tr->destroy_parsed_source($parsed_source)
+
+Removes $parsed_source from memory. 
+
+=item $tr->set_stylesheet_param($key, $val)
+
+Set an XSLT parameter, $key is the param name and val is the assigned value. Returns nothing.
+
+ $tr->set_stylesheet_param("id", 777);
+ $tr->set_stylesheet_param("user", "'johndoe'");
+ my $res = $tr->transform_to_file($source, $xsl, $dest);
+
+=item $tr->install_external_function($namespace, $function_name, $function)
+
+Install a user defined function as an extension. Example:
+
+ my $namespace = "http://ExternalFunction.xalan-c++.xml.apache.org";
+ my $func_name = "square-root";
+ my $func = sub {
+    my @args = @_;
+    if (@args != 1) {
+        warn "square-root accepts exactly one arg!";
+        return undef;
+    } 
+    return POSIX::sqrt($args[0]);
+ };
+
+ $tr->install_external_function($namespace, $func_name, $func);
+ my $res = $tr->transform_to_file($source, $xsl, $dest);
+
+The function to install B<must> return a scalar. In case of fatal error,
+don't C<die()>, but you should return undef. 
+
+Take a look at Xalan/t/08external.t for more usage variations.
+
 =item $tr->errstr()
 
 Returns current error string.
 
 =back
 
+=head1 A NOTE ON OBJECTS CLEANING UP
+
+C<XML::Xalan::Transformer> is an interface to XalanTransformer class, a C++
+class which internally keeps a list of compiled stylesheet objects and another 
+list of parsed source objects. Upon an XalanTransformer object destruction,
+those lists are iterated and each element of them is deleted. Deleting an
+element which is no longer exist causes a segfault, thereby I do not provide
+destructors for C<XML::Xalan::CompiledStylesheet> and
+C<XML::Xalan::ParsedSource>, since these will conflict with one from
+C<XML::Xalan::Transformer>.
+
+As a consequence, if you write a code which runs an
+C<XML::Xalan::Transformer> object for a long time and using either compiled
+stylesheet or parsed source, be careful to call the appropriate 
+C<destroy_stylesheet()> or C<destroy_parsed_source()> to remove it from the 
+internal list (thus, from the memory) once it's no longer used. Otherwise,
+the memory used will be accumulated regardless the objects are already out of
+scope, and the wasted allocated memory will be freed only when the
+C<XML::Xalan::Transformer> object runs out of scope. 
+
+For example:
+
+ my $tr = new XML::Xalan::Transformer;
+ my $compiled = $tr->compile_stylesheet_file($stylesheet);
+ my $res = $tr->transform_to_file($source, $compiled, $dest);
+
+ # $compiled will be used for another stylesheet, then 
+ # it's necessary to destroy it explicitly first:
+ $tr->destroy_stylesheet($compiled);
+
+ # now it's safe to use for another stylesheet
+ $compiled = $tr->compile_stylesheet_file($another_stylesheet);
+
+=head1 TODO
+
+C<set_stylesheet_param()> should accept a hash ref instead, so several
+parameters can be passed at once. 
+
 =head1 AUTHOR
 
 Edwin Pratomo, edpratomo@cpan.org
 
-=head1 SEE ALSO
-
-XML::Xalan(3).
-
 =cut
